==> lxqt-l10n-0.11.0.tar.xz: lxqt-l10n-0.11.0/lxqt-notificationd/lxqt-config-notificationd/lxqt-config-notificationd_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>AdvancedSettings</name>
    <message>
        <source>Menu Configuration</source>
        <translation type="vanished">Configuração do menu</translation>
    </message>
    <message>
        <source>Notification Duration</source>
        <translation type="vanished">Duração da notificação</translation>
    </message>
    <message>
        <source>For some the notification&apos;s expiration time is dependent on the notification server&apos;s settings.</source>
        <translation type="vanished">Para algumas notificações, o tempo limite depende das definições das notificações do servidor.</translation>
    </message>
    <message>
        <source>&quot;Server Decides&quot; Time:</source>
        <translation type="vanished">Tempo para &quot;Decisão do servidor&quot;:</translation>
    </message>
    <message>
        <location filename="../../../advancedsettings.ui" line="25"/>
        <source>Width:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../advancedsettings.ui" line="49"/>
        <source>Spacing:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../advancedsettings.ui" line="68"/>
        <source>Duration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../advancedsettings.ui" line="80"/>
        <source>Some notifications set their own on-screen duration.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../advancedsettings.ui" line="92"/>
        <source>Default duration:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../advancedsettings.ui" line="99"/>
        <source> sec</source>
        <translation> seg</translation>
    </message>
    <message>
        <location filename="../../../advancedsettings.ui" line="17"/>
        <source>Sizes</source>
        <translation>Tamanhos</translation>
    </message>
    <message>
        <source>Notification Spacing:</source>
        <translation type="vanished">Espaçamento da notificação:</translation>
    </message>
    <message>
        <location filename="../../../advancedsettings.ui" line="32"/>
        <location filename="../../../advancedsettings.ui" line="56"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <source>Notification Width:</source>
        <translation type="vanished">Largura da notificaçao:</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../../../basicsettings.ui" line="23"/>
        <source>Basic Settings</source>
        <translation>Definições básicas</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.ui" line="30"/>
        <source>Position on screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display Notifications</source>
        <translation type="vanished">Mostrar notificações</translation>
    </message>
    <message>
        <source>Top/Left</source>
        <translation type="vanished">Cima/Esquerda</translation>
    </message>
    <message>
        <source>Top/Right</source>
        <translation type="vanished">Cima/Direita</translation>
    </message>
    <message>
        <source>Bottom/Left</source>
        <translation type="vanished">Baixo/Esquerda</translation>
    </message>
    <message>
        <source>Bottom/Right</source>
        <translation type="vanished">Baixo/Direita</translation>
    </message>
    <message>
        <source>Test Notification</source>
        <translation type="vanished">Testar notificação</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.cpp" line="57"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; No notifications daemon is running.
A fallback will be used.</source>
        <translation>&lt;b&gt;Aviso:&lt;/b&gt; o serviço de notificaçoes não está em execução.
Será utilizada uma solução alternativa.</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.cpp" line="60"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; A third-party notifications daemon (%1) is running.
These settings won&apos;t have any effect on it!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../basicsettings.cpp" line="117"/>
        <source>Notification demo </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../basicsettings.cpp" line="118"/>
        <source>This is a test notification.
 All notifications will now appear here on LXQt.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;b&gt;Warning:&lt;/b&gt; A third-party notifications daemon (%1) is running.
These settings won&apos;t have an effect on it!</source>
        <translation type="vanished">&lt;b&gt;Aviso:&lt;/b&gt; já está a ser executado um serviço de notificações (%1).
Estas definições não produzirão qualquer efeito!</translation>
    </message>
    <message>
        <source>Notification Summary</source>
        <translation type="vanished">Resumo da notificação</translation>
    </message>
    <message>
        <source>Notification Body</source>
        <translation type="vanished">Corpo da notificação</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../../mainwindow.cpp" line="40"/>
        <source>Desktop Notifications</source>
        <translation>Notificações do ambiente de trabalho</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="43"/>
        <source>Basic Settings</source>
        <translation>Definições básicas</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="47"/>
        <source>Advanced Settings</source>
        <translation>Definições avançadas</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-notificationd/lxqt-config-notificationd/lxqt-config-notificationd_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>AdvancedSettings</name>
    <message>
        <source>Menu Configuration</source>
        <translation>Configuração do menu</translation>
    </message>
    <message>
        <source>Notification Duration</source>
        <translation>Duração da notificação</translation>
    </message>
    <message>
        <source>For some the notification&apos;s expiration time is dependent on the notification server&apos;s settings.</source>
        <translation>Para algumas notificações, o tempo limite depende das definições das notificações do servidor.</translation>
    </message>
    <message>
        <source>&quot;Server Decides&quot; Time:</source>
        <translation>Tempo para &quot;Decisão do servidor&quot;:</translation>
    </message>
    <message>
        <location filename="../../../advancedsettings.ui" line="25"/>
        <source>Width:</source>
        <translation>Largura:</translation>
    </message>
    <message>
        <location filename="../../../advancedsettings.ui" line="49"/>
        <source>Spacing:</source>
        <translation>Espaçamento:</translation>
    </message>
    <message>
        <location filename="../../../advancedsettings.ui" line="68"/>
        <source>Duration</source>
        <translation>Duração</translation>
    </message>
    <message>
        <location filename="../../../advancedsettings.ui" line="80"/>
        <source>Some notifications set their own on-screen duration.</source>
        <translation>Algumas notificações definem a sua duração no ecrã.</translation>
    </message>
    <message>
        <location filename="../../../advancedsettings.ui" line="92"/>
        <source>Default duration:</source>
        <translation>Duração padrão:</translation>
    </message>
    <message>
        <location filename="../../../advancedsettings.ui" line="99"/>
        <source> sec</source>
        <translation> seg</translation>
    </message>
    <message>
        <location filename="../../../advancedsettings.ui" line="17"/>
        <source>Sizes</source>
        <translation>Tamanhos</translation>
    </message>
    <message>
        <source>Notification Spacing:</source>
        <translation>Espaçamento da notificação:</translation>
    </message>
    <message>
        <location filename="../../../advancedsettings.ui" line="32"/>
        <location filename="../../../advancedsettings.ui" line="56"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <source>Notification Width:</source>
        <translation>Largura da notificação:</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../../../basicsettings.ui" line="23"/>
        <source>Basic Settings</source>
        <translation>Definições básicas</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.ui" line="30"/>
        <source>Position on screen</source>
        <translation>Posição no ecrã</translation>
    </message>
    <message>
        <source>Display Notifications</source>
        <translation>Mostrar notificações</translation>
    </message>
    <message>
        <source>Top/Left</source>
        <translation>Cima/Esquerda</translation>
    </message>
    <message>
        <source>Top/Right</source>
        <translation>Cima/Direita</translation>
    </message>
    <message>
        <source>Bottom/Left</source>
        <translation>Baixo/Esquerda</translation>
    </message>
    <message>
        <source>Bottom/Right</source>
        <translation>Baixo/Direita</translation>
    </message>
    <message>
        <source>Test Notification</source>
        <translation>Testar notificação</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.cpp" line="57"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; No notifications daemon is running.
A fallback will be used.</source>
        <translation>&lt;b&gt;Aviso:&lt;/b&gt; o serviço de notificaçoes não está em execução.
Será utilizada uma solução alternativa.</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.cpp" line="60"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; A third-party notifications daemon (%1) is running.
These settings won&apos;t have any effect on it!</source>
        <translation>&lt;b&gt;Aviso:&lt;/b&gt;já está a ser executado o serviço de notificações (%1).
Estas definições não produzirão qualquer efeito!</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.cpp" line="117"/>
        <source>Notification demo </source>
        <translation>Demonstração </translation>
    </message>
    <message>
        <location filename="../../../basicsettings.cpp" line="118"/>
        <source>This is a test notification.
 All notifications will now appear here on LXQt.</source>
        <translation>Esta é uma notificação de teste.
Todas as suas notificações aparecerão aqui.</translation>
    </message>
    <message>
        <source>&lt;b&gt;Warning:&lt;/b&gt; A third-party notifications daemon (%1) is running.
These settings won&apos;t have an effect on it!</source>
        <translation>&lt;b&gt;Aviso:&lt;/b&gt; já está a ser executado o serviço de notificações (%1).
Estas definições não produzirão qualquer efeito!</translation>
    </message>
    <message>
        <source>Notification Summary</source>
        <translation>Resumo da notificação</translation>
    </message>
    <message>
        <source>Notification Body</source>
        <translation>Texto da notificação</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../../mainwindow.cpp" line="40"/>
        <source>Desktop Notifications</source>
        <translation>Notificações do ambiente de trabalho</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="43"/>
        <source>Basic Settings</source>
        <translation>Definições básicas</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="47"/>
        <source>Advanced Settings</source>
        <translation>Definições avançadas</translation>
    </message>
</context>
</TS>
